Bigger Package API
==================

.. automodule:: bigger
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

.. rubric:: Classes

.. autosummary::
    :toctree: ../generated
    :nosignatures:
    :template: summary.rst

    ~encoding.Move
    ~encoding.Encoding
    ~lamination.Lamination
    ~triangulation.Triangulation
    ~mappingclassgroup.MappingClassGroup

